@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Log::Dispatchouli::Proxy;
 BEGIN {
-  $Log::Dispatchouli::Proxy::VERSION = '1.102350';
+  $Log::Dispatchouli::Proxy::VERSION = '2.005';
 }
 # ABSTRACT: a simple wrapper around Log::Dispatch
 
@@ -38,6 +38,9 @@ sub proxy  {
 sub parent { $_[0]{parent} }
 sub logger { $_[0]{logger} }
 
+sub ident     { $_[0]{logger}->ident }
+sub config_id { $_[0]{logger}->config_id }
+
 sub set_prefix   { $_[0]{prefix} = $_[1] }
 sub get_prefix   { $_[0]{prefix} }
 sub clear_prefix { undef $_[0]{prefix} }
@@ -117,7 +120,7 @@ Log::Dispatchouli::Proxy - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 1.102350
+version 2.005
 
 =head1 DESCRIPTION
 
@@ -150,7 +153,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
